@@ -23,9 +23,11 @@ import optuna.integration.lightgbm
 from ._common import logger
 
 
-__version__ = "0.11.0"
+__version__ = "0.12.0"
 _T1 = TypeVar("_T1")
 
+_CachedCallableV1_CACHE_V1 = dict()
+
 
 class DataIteratorV1(Generic[_T1]):
     def __init__(
@@ -92,6 +94,20 @@ class LabelEncoderV1(Generic[_T1]):
         return self._label_of_int[i]
 
 
+class CachedCallableV1:
+    __slots__ = ("_k",)
+
+    @staticmethod
+    def set(k, v):
+        _CachedCallableV1_CACHE_V1[k] = v
+
+    def __init__(self, k):
+        self._k = k
+
+    def __call__(self, *args, **kwargs):
+        return _CachedCallableV1_CACHE_V1[self._k](*args, **kwargs)
+
+
 @contextlib.contextmanager
 def timing_v1(msg, fn=logger.info):
     t1 = time.monotonic()
@@ -148,7 +164,7 @@ def intersect1d_v1(xss: Sequence[Sequence[_T1]], assume_unique=False) -> Sequenc
 
 
 def batch_v1(
-    xs: Iterable[_T1], n: int, drop_reminder=False
+    xs: Iterable[_T1], n: int, drop_reminder: bool = False
 ) -> Generator[List[_T1], None, None]:
     if n < 1:
         raise ValueError(f"`n` should be >= 1: {n}")
